@@ -65,7 +65,6 @@
 #define GTK_FILE_CHOOSER_BUTTON_GET_PRIVATE(object) (GTK_FILE_CHOOSER_BUTTON ((object))->priv)
 
 #define DEFAULT_TITLE		N_("Select A File")
-#define HOME_DISPLAY_NAME	N_("Home")
 #define DESKTOP_DISPLAY_NAME	N_("Desktop")
 #define FALLBACK_DISPLAY_NAME	N_("(None)")
 #define FALLBACK_ICON_NAME	"stock_unknown"
@@ -555,7 +554,7 @@ gtk_file_chooser_button_remove_shortcut_folder (GtkFileChooser     *chooser,
 
       pos = model_get_type_position (GTK_FILE_CHOOSER_BUTTON (chooser),
 				     ROW_TYPE_SHORTCUT);
-      g_assert (gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, pos));
+      gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, pos);
 
       do
 	{
@@ -844,7 +843,7 @@ gtk_file_chooser_button_finalize (GObject *object)
   if (priv->old_path)
     gtk_file_path_free (priv->old_path);
 
-  g_assert (gtk_tree_model_get_iter_first (priv->model, &iter));
+  gtk_tree_model_get_iter_first (priv->model, &iter);
 
   do
     {
@@ -1093,7 +1092,7 @@ change_icon_theme (GtkFileChooserButton *button)
 
   update_label_and_image (button);
 
-  g_assert (gtk_tree_model_get_iter_first (priv->model, &iter));
+  gtk_tree_model_get_iter_first (priv->model, &iter);
 
   theme = get_icon_theme (GTK_WIDGET (button));
 
@@ -1322,6 +1321,7 @@ static inline void
 model_add_special (GtkFileChooserButton *button)
 {
   const gchar *homedir;
+  const gchar *display_name;
   gchar *desktopdir = NULL;
   GtkListStore *store;
   GtkTreeIter iter;
@@ -1337,6 +1337,7 @@ model_add_special (GtkFileChooserButton *button)
   if (homedir)
     {
       path = gtk_file_system_filename_to_path (button->priv->fs, homedir);
+      display_name = get_display_name_for_path (button->priv->fs, path);
       pixbuf = gtk_file_system_render_icon (button->priv->fs, path,
 					    GTK_WIDGET (button),
 					    button->priv->icon_size, NULL);
@@ -1344,13 +1345,14 @@ model_add_special (GtkFileChooserButton *button)
       pos++;
       gtk_list_store_set (store, &iter,
 			  ICON_COLUMN, pixbuf,
-			  DISPLAY_NAME_COLUMN, _(HOME_DISPLAY_NAME),
+			  DISPLAY_NAME_COLUMN, display_name,
 			  TYPE_COLUMN, ROW_TYPE_SPECIAL,
 			  DATA_COLUMN, path,
 			  -1);
 
       if (pixbuf)
 	g_object_unref (pixbuf);
+      g_free (display_name);
       button->priv->n_special++;
 
 #ifndef G_OS_WIN32
@@ -1737,7 +1739,7 @@ update_combo_box (GtkFileChooserButton *button)
 
   priv = GTK_FILE_CHOOSER_BUTTON_GET_PRIVATE (button);
 
-  g_assert (gtk_tree_model_get_iter_first (priv->filter_model, &iter));
+  gtk_tree_model_get_iter_first (priv->filter_model, &iter);
 
   paths = _gtk_file_chooser_get_paths (GTK_FILE_CHOOSER (priv->dialog));
 
@@ -1803,7 +1805,7 @@ update_combo_box (GtkFileChooserButton *button)
       gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (priv->filter_model));
 
       pos = model_get_type_position (button, ROW_TYPE_CURRENT_FOLDER);
-      g_assert (gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, pos));
+      gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, pos);
 
       gtk_tree_model_filter_convert_child_iter_to_iter (GTK_TREE_MODEL_FILTER (priv->filter_model),
 							&filter_iter, &iter);
@@ -2170,7 +2172,7 @@ dialog_notify_cb (GObject    *dialog,
 
 	  pos = model_get_type_position (user_data,
 					 ROW_TYPE_CURRENT_FOLDER);
-	  g_assert (gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, pos));
+	  gtk_tree_model_iter_nth_child (priv->model, &iter, NULL, pos);
 
 	  data = NULL;
 	  gtk_tree_model_get (priv->model, &iter, DATA_COLUMN, &data, -1);
