@@ -239,7 +239,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
 				   g_param_spec_string ("ui",
  							P_("Merged UI definition"),
 							P_("An XML string describing the merged UI"),
-							NULL,
+							"<ui>\n</ui>",
 							GTK_PARAM_READABLE));
 
 
@@ -470,7 +470,7 @@ gtk_ui_manager_get_property (GObject         *object,
       g_value_set_boolean (value, self->private_data->add_tearoffs);
       break;
     case PROP_UI:
-      g_value_set_string (value, gtk_ui_manager_get_ui (self));
+      g_value_take_string (value, gtk_ui_manager_get_ui (self));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -761,30 +761,36 @@ gtk_ui_manager_get_widget (GtkUIManager *self,
   return GTK_UI_MANAGER_GET_CLASS (self)->get_widget (self, path);
 }
 
+typedef struct {
+  GtkUIManagerItemType types;
+  GSList *list;
+} ToplevelData;
+
 static void
 collect_toplevels (GNode   *node, 
 		   gpointer user_data)
 {
-  struct {
-    GtkUIManagerItemType types;
-    GSList *list;
-  } *data = user_data;
+  ToplevelData *data = user_data;
 
-  switch (NODE_INFO (node)->type) {
-  case NODE_TYPE_MENUBAR:
-    if (data->types & GTK_UI_MANAGER_MENUBAR)
-      data->list = g_slist_prepend (data->list, NODE_INFO (node)->proxy);
-    break;
-  case NODE_TYPE_TOOLBAR:
-    if (data->types & GTK_UI_MANAGER_TOOLBAR)
-      data->list = g_slist_prepend (data->list, NODE_INFO (node)->proxy);
-    break;
-  case NODE_TYPE_POPUP:
-    if (data->types & GTK_UI_MANAGER_POPUP)
-      data->list = g_slist_prepend (data->list, NODE_INFO (node)->proxy);
-    break;
-  default: ;
-  }
+  if (NODE_INFO (node)->proxy)
+    {
+      switch (NODE_INFO (node)->type) 
+	{
+	case NODE_TYPE_MENUBAR:
+	  if (data->types & GTK_UI_MANAGER_MENUBAR)
+	data->list = g_slist_prepend (data->list, NODE_INFO (node)->proxy);
+	  break;
+	case NODE_TYPE_TOOLBAR:
+      if (data->types & GTK_UI_MANAGER_TOOLBAR)
+	data->list = g_slist_prepend (data->list, NODE_INFO (node)->proxy);
+      break;
+	case NODE_TYPE_POPUP:
+	  if (data->types & GTK_UI_MANAGER_POPUP)
+	    data->list = g_slist_prepend (data->list, NODE_INFO (node)->proxy);
+	  break;
+	default: ;
+	}
+    }
 }
 
 /**
@@ -805,10 +811,7 @@ GSList *
 gtk_ui_manager_get_toplevels (GtkUIManager         *self,
 			      GtkUIManagerItemType  types)
 {
-  struct {
-    GtkUIManagerItemType types;
-    GSList *list;
-  } data;
+  ToplevelData data;
 
   g_return_val_if_fail (GTK_IS_UI_MANAGER (self), NULL);
   g_return_val_if_fail ((~(GTK_UI_MANAGER_MENUBAR | 
@@ -2520,12 +2523,6 @@ update_node (GtkUIManager *self,
 	      
 	      gtk_toolbar_insert (GTK_TOOLBAR (toolbar),
 				  GTK_TOOL_ITEM (info->proxy), pos);
-	      
-	      /* FIXME: we must trigger the notify::tooltip handler, since 
-	       * tooltips on toolitems can't be set before the toolitem 
-	       * is added to the toolbar.
-	       */
-	      g_object_notify (G_OBJECT (action), "tooltip");
 	    }
 	}
       else
@@ -2535,6 +2532,13 @@ update_node (GtkUIManager *self,
 						NULL);
 	  gtk_action_connect_proxy (action, info->proxy);
 	}
+
+      /* FIXME: we must trigger the notify::tooltip handler, since 
+       * tooltips on toolitems can't be set before the toolitem 
+       * is added to the toolbar.
+       */
+      g_object_notify (G_OBJECT (action), "tooltip");
+
       g_signal_connect (info->proxy, "notify::visible",
 			G_CALLBACK (update_smart_separators), NULL);
       break;
